/*==========================================================================
 *
 *  Copyright (C) 1995-1997 Microsoft Corporation. All Rights Reserved.
 *
 *  File:       input.c
 *  Content:    DirectInput functionality for Multi-player duel
 *
 *
 ***************************************************************************/


#include "input.h" 




/*
*
* InitInput
*
* Initialize DirectInput objects & devices
*
*/
BOOL InitInput(void)
{

   HRESULT  hRes;

	// try to create di object (DIRECTINPUT_VERSION == DX5)
	if(DirectInputCreate(hwnd, 0x0500, &lpdi, NULL) != DI_OK)
	{
      // creation failed, try DX3 compatibility
      if(DirectInputCreate(hwnd, 0x0300, &lpdi, NULL) != DI_OK)
      {
         ShowError(IDS_DINPUT_ERROR_DIC);
         return FALSE;
      }
	}


	// try to create keyboard device
        if(lpdi->CreateDevice(lpdi, &guid, &lpdiKeyboard, NULL) !=DI_OK)
	{
		ShowError(IDS_DINPUT_ERROR_CD);
		return FALSE;
	}

        // Tell DirectInput that we want to receive data in keyboard format
        if (lpdiKeyboard->SetDataFormat(lpdiKeyboard, &c_dfDIKeyboard) != DI_OK)
        {
                ShowError(IDS_DINPUT_ERROR_DF);
                return FALSE;
        }

        // set cooperative level
        if(lpdiKeyboard->SetCooperativeLevel(lpdiKeyboard, ghWndMain,
                         DISCL_NONEXCLUSIVE | DISCL_FOREGROUND) != DI_OK)
	{
		ShowError(IDS_DINPUT_ERROR_SP);
		return FALSE;
        }

	// try to acquire the keyboard
   hRes = lpdiKeyboard->Acquire(lpdiKeyboard);
   if(SUCCEEDED(hRes))
   {
      // keyboard was acquired
      fKeybdAcquired = TRUE;
	}
   else
   {
      // keyboard was NOT acquired
      fKeybdAcquired = FALSE;
   }

	// if we get here, all objects were created successfully
	return TRUE;	
		
}



extern "C" void CleanupInput(void)
{
	if(fKeybdAcquired)
	{
		lpdiKeyboard->Unacquire(lpdiKeyboard);
		fKeybdAcquired = FALSE;
	}

	if(lpdiKeyboard != NULL)
		lpdiKeyboard->Release(lpdiKeyboard);

	if(lpdi!= NULL)
		lpdi->lpVtbl->Release(lpdi);
	
}


/*
*
* ReacquireInputDevices
*
* Reacquires DirectInput devices as needed
*
*/
BOOL ReacquireInputDevices(void)
{
	// try to acquire the keyboard
        if(lpdiKeyboard != NULL)
        {
                lpdiKeyboard->Acquire(lpdiKeyboard);
	     }
        else
        {
                // keyboard device has not been created.
                fKeybdAcquired = FALSE;
                return FALSE;
        }

        // if we get here, we are acquired again
        fKeybdAcquired = TRUE;
        return TRUE;
}












